@@ -35,25 +35,27 @@ def train_test_validation_split_with_equal_classes(dataset: torch.utils.data.Dat
                                                    label_name: str = 'targets',
                                                    verbose:bool = False, 
                                                    batch_size: int = 16,
-                                                   num_workers: int = 16,
+                                                   num_workers: int = 0,
                                                    other_split: float = 0.2, 
                                                    validation_split: float = 0.5, 
                                                    shuffle: bool = False, 
                                                    use_sampler: bool = False, 
-                                                   pin_memory:bool = True):
+                                                   pin_memory:bool = True, 
+                                                   always_return_subsets: bool = False):
   """ Generate train, test and validation datasets and dataloaders for Pytorch ImageFolder dataset. Method relies on sklearn and pytorch. 
   If using multiple image dimensions per class, must use transforms.Resize((img_size, img_size)) or else the DataLoaders will return a error.
   Args:
       root (str, optional): Location of ImageFolder dataset. Defaults to './content/Multimini-dataset'.
       transforms (transforms.Compose, optional): List of trnasforms. Defaults to transform_original.
       verbose (bool, optional): Print out the class distributions of the devided datasets. Defaults to False.
-      batch_size (int, optional): Batch size of dataloaders. Defaults to 16.
+      batch_size (int, optional): Batch size of dataloaders. Defaults to 0. Blocks operations if set to non 0, very carefully use. 
       num_workers (int, optional): Number of workers for dataloaders. Defaults to 16.
       other_split (float, optional): How much to split for test and validation. Defaults to 0.2.
       validation_split (float, optional): How much to split from other_split into validation set. Defaults to 0.5.
       shuffle (bool, optional): To shuffle data for DataLoaders. Defaults to False.
       use_sampler (bool, optional): To directly use data_dict in DataLoaders or use SubRandomSampler. Defaults to False.
       pin_memory (bool, optional): Used when GPUs are used. Defaults to True.
+      always_return_subsets (bool, optional): If the sampler is not used, to force the method to always return correct value
   Returns:
       Tuple(Dict[str, torch.utils.data.Subset], Dict[str, torch.utils.data.DataLoader]): 
       Returns dict of split subsets and dict of split dataloaders
@@ -98,9 +100,10 @@ def train_test_validation_split_with_equal_classes(dataset: torch.utils.data.Dat
     samplers = {'train': SubsetRandomSampler(train_idx),
                 'val': SubsetRandomSampler(other_idx[test_idx]),
                 'test': SubsetRandomSampler(other_idx[valid_idx])}
-
-  data_dict = {'train' : Subset(dataset, train_idx), 'val': Subset(dataset, other_idx[valid_idx]), 'test': Subset(dataset, other_idx[valid_idx])}
-  
+  if always_return_subsets or not use_sampler:
+    data_dict = {'train' : Subset(dataset, train_idx), 'val': Subset(dataset, other_idx[valid_idx]), 'test': Subset(dataset, other_idx[test_idx])}
+  else:
+    data_dict = dataset #Return the whole dataset in case of Sampler being used.
   from torch.utils.data import DataLoader
 
   loader_dict = {x: DataLoader(data_dict[x] if not use_sampler else dataset, batch_size=batch_size, num_workers=num_workers, sampler=samplers[x] if use_sampler else None, shuffle=shuffle, pin_memory=pin_memory) for x in ['train', 'val', 'test']}
